pub struct AgentBuilder { /* private fields */ }Expand description
Builder for constructing AgentCore instances
Implementations
Sourceimpl AgentBuilder
impl AgentBuilder
Sourcepub fn new() -> AgentBuilder
pub fn new() -> AgentBuilder
Create a new agent builder
Sourcepub fn new_with_registry(
registry: &AgentRegistry,
config: &AppConfig,
session_id: Option<String>,
) -> Result<AgentCore, Error>
pub fn new_with_registry( registry: &AgentRegistry, config: &AppConfig, session_id: Option<String>, ) -> Result<AgentCore, Error>
Create an agent from the registry with the active profile This is a convenience method for CLI use
Sourcepub fn with_profile(self, profile: AgentProfile) -> AgentBuilder
pub fn with_profile(self, profile: AgentProfile) -> AgentBuilder
Set the agent profile
Sourcepub fn with_provider(self, provider: Arc<dyn ModelProvider>) -> AgentBuilder
pub fn with_provider(self, provider: Arc<dyn ModelProvider>) -> AgentBuilder
Set the model provider
Sourcepub fn with_embeddings_client(
self,
embeddings_client: EmbeddingsClient,
) -> AgentBuilder
pub fn with_embeddings_client( self, embeddings_client: EmbeddingsClient, ) -> AgentBuilder
Set a custom embeddings client
Sourcepub fn with_persistence(self, persistence: Persistence) -> AgentBuilder
pub fn with_persistence(self, persistence: Persistence) -> AgentBuilder
Set the persistence layer
Sourcepub fn with_session_id(self, session_id: impl Into<String>) -> AgentBuilder
pub fn with_session_id(self, session_id: impl Into<String>) -> AgentBuilder
Set the session ID
Sourcepub fn with_config(self, config: AppConfig) -> AgentBuilder
pub fn with_config(self, config: AppConfig) -> AgentBuilder
Set the application configuration (used to derive defaults)
Sourcepub fn with_tool_registry(
self,
tool_registry: Arc<ToolRegistry>,
) -> AgentBuilder
pub fn with_tool_registry( self, tool_registry: Arc<ToolRegistry>, ) -> AgentBuilder
Set the tool registry
Sourcepub fn with_policy_engine(
self,
policy_engine: Arc<PolicyEngine>,
) -> AgentBuilder
pub fn with_policy_engine( self, policy_engine: Arc<PolicyEngine>, ) -> AgentBuilder
Set the policy engine
Sourcepub fn with_agent_name(self, agent_name: impl Into<String>) -> AgentBuilder
pub fn with_agent_name(self, agent_name: impl Into<String>) -> AgentBuilder
Set the logical agent name (used for telemetry/logging)