pub trait MeshState {
// Required method
fn mesh_registry(&self) -> &MeshRegistry;
}Expand description
Extension trait to add mesh registry to app state
pub trait MeshState {
// Required method
fn mesh_registry(&self) -> &MeshRegistry;
}Extension trait to add mesh registry to app state