pub struct VectorClock { /* private fields */ }Expand description
Vector clock for tracking causality in distributed systems Each instance maintains its own logical clock version
Implementations
Sourceimpl VectorClock
impl VectorClock
Sourcepub fn new() -> VectorClock
pub fn new() -> VectorClock
Create a new empty vector clock
Sourcepub fn from_json(json: &str) -> Result<VectorClock, Error>
pub fn from_json(json: &str) -> Result<VectorClock, Error>
Create a vector clock from a JSON string
Sourcepub fn get(&self, instance_id: &str) -> i64
pub fn get(&self, instance_id: &str) -> i64
Get the version for a specific instance (0 if not present)
Sourcepub fn set(&mut self, instance_id: String, version: i64)
pub fn set(&mut self, instance_id: String, version: i64)
Set the version for a specific instance
Sourcepub fn increment(&mut self, instance_id: &str) -> i64
pub fn increment(&mut self, instance_id: &str) -> i64
Increment the version for the given instance
Sourcepub fn merge(&mut self, other: &VectorClock)
pub fn merge(&mut self, other: &VectorClock)
Merge another vector clock, taking the maximum version for each instance This is used when receiving updates from other instances
Sourcepub fn compare(&self, other: &VectorClock) -> ClockOrder
pub fn compare(&self, other: &VectorClock) -> ClockOrder
Compare this clock with another to determine causality relationship Returns:
- Before: self happened-before other (self is older)
- After: other happened-before self (self is newer)
- Concurrent: neither happened-before the other (conflict)
- Equal: clocks are identical
Sourcepub fn happens_before(&self, other: &VectorClock) -> bool
pub fn happens_before(&self, other: &VectorClock) -> bool
Check if this clock happened-before another (causally precedes)
Sourcepub fn is_concurrent(&self, other: &VectorClock) -> bool
pub fn is_concurrent(&self, other: &VectorClock) -> bool
Check if this clock is concurrent with another (conflict)
Sourcepub fn is_equal(&self, other: &VectorClock) -> bool
pub fn is_equal(&self, other: &VectorClock) -> bool
Check if this clock is equal to another
Sourcepub fn instance_count(&self) -> usize
pub fn instance_count(&self) -> usize
Get the number of instances tracked